pub struct EarlyCmdline {
pub log_level: LevelFilter,
pub has_early_console: bool,
}Expand description
The early command line arguments.
crate::early_cmdline_parser can be used to specify how this is parsed
from the kernel command line. If it is not specified, we will use the
default values (see the field documentation).
Fields
log_level: LevelFilterThe log level filter.
The default value is LevelFilter::Debug.
has_early_console: boolWhether to enable the early console.
The default value is true.
We choose true as the default value
in order to give a minimal OSTD-based kernel
(e.g., the one created with osdk test)
access to an early console and thus enable logging.
This is convenient for development purpose.
On the other hand,
blindly assuming a deployment platform is attached
to a UART-based console is
unacceptable for a production-grade kernel,
which should instead register crate::early_cmdline_parser
to acquire this information from the kernel parameter.